
# v0.3.0

Major overhaul.
- Renamed package to filefinder.
- Slight changes in custom regex syntax. Will break previous pre-regex.
- Can specify matcher with a format string.
- Custom classes containing matches results.
- Only search subdirectories matching the regex.
- Log messages to debug regex.
- Fix matchers with value or string.
- Unfix matchers.
- New default regex elements.


### v0.2.1

- [2021-02-04] Fix multiple matchers at once.

## v0.2.0

- [2021-01-28] Add possibility to retrieve files in a nested list.
- [2021-01-28] Fix warning on missing matchers in `get_date`.

### v0.1.1

- [2021-01-20] Fix fixing matcher by index.

## v0.1.0


